// BMultiLineStringView
// (c) 1997 Steven R. Loomis
// srl@monkey.sbay.org
// < http://www.monkey.sbay.org/~srl/ >
// do what you want with it but give me credit somewhere


// this is a multi line string view
// it line breaks on \n's (DOES NOT line wrap)
// fixed font

#pragma once

#include <View.h>

class BMultiLineStringView : public BView
{
public:
				BMultiLineStringView(BRect frame,
							 char *name,
							  char *text = "");  // the initial text (not adopted)
virtual	void	AttachedToWindow();
virtual	void	Draw(BRect updateRect);

	void	SetText(const char *text); // sets text (not adopted)
	
private:
	char	fText[1024];
		

};