/*
	
	HelloView.h
	
	Copyright 1995 Be Incorporated, All Rights Reserved.
	
*/

#ifndef HELLO_VIEW_H
#define HELLO_VIEW_H

#ifndef _VIEW_H
#include <View.h>
#endif

#include "MultiLineStringView.h"

class HelloView : public BView {

public:
				HelloView(BRect frame, char *name); 
virtual	void	AttachedToWindow();
virtual	void	Draw(BRect updateRect);

virtual void MessageReceived(BMessage *message);
private:
	BMultiLineStringView *fStringView;
//	BScrollView *fScrollView;
};

#endif
