/*
	
	HelloWindow.cpp
	
	Copyright 1995 Be Incorporated, All Rights Reserved.
	
*/

#ifndef _APPLICATION_H
#include <Application.h>
#endif

#ifndef HELLO_WINDOW_H
#include "HelloWindow.h"
#endif

#include "README.h"

void set_palette_entry(long i,rgb_color c);

HelloWindow::HelloWindow(BRect frame)
				: BWindow(frame, kWindowTitle , B_TITLED_WINDOW, B_NOT_ZOOMABLE)
{
}

bool HelloWindow::QuitRequested()
{
	be_app->PostMessage(B_QUIT_REQUESTED);
	return(TRUE);
}
