/*
	
	HelloWorld.h
	
	Copyright 1995 Be Incorporated, All Rights Reserved.

*/

#ifndef HELLO_WORLD_H
#define HELLO_WORLD_H

#ifndef _APPLICATION_H
#include <Application.h>
#endif

class HelloApplication : public BApplication {

public:
					HelloApplication();
};

#endif
