#define kVersion "0.0"
#define kProgram "DropInspector"
#define kWindowTitle  kProgram " " kVersion

#define kSignature "application/x-vnd.org.monkey.sbay.srl.DropInspector"
#define kStartupText kProgram " " kVersion "\n" \
"Drag something into this space to see what types are\n" \
"contained therein.  Steven R. Loomis srl@monkey.sbay.org\n" \
"http://www.monkey.sbay.org/~srl/\n"

/*

DropInspector 0.0

1997-09-24  srl	  initial version

shows you what types are in something
simply drag SOMETHING into this window
also shows off a simple stupid multi line static text view

// (c) 1997 Steven R. Loomis
// srl@monkey.sbay.org
// < http://www.monkey.sbay.org/~srl/ >
// do what you want with it but give me credit somewhere

*/